@@ -72,13 +72,19 @@ bd_ans_drv_InitANS(BOARD_PRIVATE_STRUCT *bps,
     
     /* set all the required status fields to this driver's 
      * status fields. */
-    iANSdata->link_status = &(((bd_config_t *)bps)->bddp->cur_link_status);
-    iANSdata->line_speed  = &(((bd_config_t *)bps)->bddp->ans_line_speed);
-    iANSdata->duplex      = &(((bd_config_t *)bps)->bddp->ans_dplx_mode);
+    iANSdata->link_status =
+        (UINT32 *)&(((bd_config_t *)bps)->bddp->cur_link_status);
+    
+    iANSdata->line_speed  =
+        (UINT32 *)&(((bd_config_t *)bps)->bddp->ans_line_speed);
+    
+    iANSdata->duplex      =
+        (UINT32 *)&(((bd_config_t *)bps)->bddp->ans_dplx_mode);
+    
     iANSdata->hw_fail   = NULL;
     iANSdata->suspended = NULL;
     iANSdata->in_reset  = NULL;
-}                            
+}
 
 
 
@@ -176,8 +182,21 @@ bd_ans_drv_ConfigureVlan(BOARD_PRIVATE_STRUCT *bps)
      * and tag_mode flags are set.  The driver should not modify
      * the flag
      */
-
-    return e100_configure(bps) ? BD_ANS_SUCCESS : BD_ANS_FAILURE;
+    iANSsupport_t *iANSdata = ANS_PRIVATE_DATA_FIELD(bps);
+    
+    if (iANSdata->iANS_status == IANS_COMMUNICATION_UP) {
+        
+#ifdef IANS_BASE_VLAN_TAGGING
+        if (iANSdata->vlan_mode == IANS_VLAN_MODE_ON) {
+            e100_config_enable_tagging(bps, B_TRUE);
+            
+        } else {
+            e100_config_enable_tagging(bps, B_FALSE);
+        }
+#endif
+    }
+    
+    return e100_config(bps) ? BD_ANS_SUCCESS : BD_ANS_FAILURE;
 }
 
 
