@@ -81,21 +81,19 @@ bd_ans_hw_flags(BOARD_PRIVATE_STRUCT *bps, UINT16 revid)
     UINT16 CompatibilityFlagsReg;
     UINT32 flags = 0;
     
-    /* check to see if we are a 559 or greater adapter */
-    if (revid >= I82559_REV_ID) {
-        /* this is not a 82557 or 82558, so we should keep checking */
-        CompatibilityFlagsReg = READ_EEPROM(bps, EEPROM_COMPATIBILITY_FLAGS);
-        /* get hw flags from the EEPROM */
-        if (!(HIGH_BYTE(CompatibilityFlagsReg) & EEPROM_COMPATIBILITY_BIT_4))
-            flags &= !IANS_BD_FLAG4;
-        else
-            flags |= IANS_BD_FLAG4;
-    } 
-    else
-    {
+    if (revid < I82559_REV_ID) {
         flags |= IANS_BD_FLAG4;
+        
+    } else {
+        CompatibilityFlagsReg = READ_EEPROM(bps, EEPROM_COMPATIBILITY_FLAGS);
+        
+        if ((HIGH_BYTE(CompatibilityFlagsReg) & EEPROM_COMPATIBILITY_BIT_4) &&
+            !(HIGH_BYTE(CompatibilityFlagsReg) & EEPROM_COMPATIBILITY_BIT_2)) {
+            
+            flags |= IANS_BD_FLAG4;
+        }
     }
-
+    
     return flags;
 }
           
@@ -115,11 +113,8 @@ bd_ans_hw_SupportsIEEETagging(BOARD_PRIVATE_STRUCT *bps, UINT16 revid)
 BD_ANS_BOOLEAN
 bd_ans_hw_IsQtagPacket(BOARD_PRIVATE_STRUCT *bps, HW_RX_DESCRIPTOR *rxd)
 {
-    cb_header_status_word *header;
-
-    header = (cb_header_status_word *) &(RXD_STATUS(rxd));
     /* check the T bit */
-    if (header->underrun) {
+     if (RXD_STATUS(rxd) & BIT_12) {  /* underrun */
         return BD_ANS_TRUE;
     }
     return BD_ANS_FALSE;
@@ -141,17 +136,12 @@ bd_ans_hw_GetVlanId(BOARD_PRIVATE_STRUCT *bps,
     HW_RX_DESCRIPTOR *rxd)
 {
     UINT16 VlanId = INVALID_VLAN_ID;
-    cb_header_status_word *status;
-
-
-    status = (cb_header_status_word *) &(RXD_STATUS(rxd));
 
     /* check the T bit */
-    if (status->underrun) 
-    {
+    if (RXD_STATUS(rxd) & BIT_12) { /* underrun */
         VlanId = BYTE_SWAP_WORD(RXD_VLANID(rxd)) & VLAN_ID_MASK;
         /* clear out the vlan id bits just to be safe */
-        status->underrun = 0;
+        RXD_STATUS(rxd) &= ~BIT_12;
         RXD_VLANID(rxd) = 0;
     }
     DEBUGLOG1("bd_ans_hw_GetVlanId: got %d\n", VlanId);
@@ -168,34 +158,7 @@ bd_ans_hw_GetVlanId(BOARD_PRIVATE_STRUCT *bps,
 void
 bd_ans_hw_ConfigEnableTagging(UINT8 *ConfigBytes, UINT16 rev_id)
 {
-    DEBUGLOG("bd_ans_hw_ConfigEnableTagging: enter\n");
-    /* assumption is that ConfigBytes has already been initialized
-     * to default values.
-     */
-    
-    /* first we need to enable reception of larger packets.  This
-     * is config byte 18.
-     */                                                 
-    if (rev_id >= D101B_REV_ID)
-        *(ConfigBytes + 18) |= CB_CFIG_LONG_RX_OK;
-    
-    /* for tagging only mode, (priority only), we would accept packets
-     * only on vlanid 0.  Since 8255x does not have a way to filter this
-     * in hardware, we need to go ahead and enable tag stripping/insertion
-     * anyway, and assume that softwar will deal with filtering the 
-     * packet correctly.  We can only enable hw vlan offloading on 82550
-     * and above
-     */
-    if (rev_id >= GAMLA_REV_ID) 
-    {
-        /* assumption is that the rest of the GAMLA configuration is 
-         * handled by the driver for other features and has been setup
-         * already.  This includes putting the driver in Gamla receive
-         * mode, enabling the extended RFD and TCB structures etc.
-         * here we only enable the vlan tag stripping.
-         */
-        *(ConfigBytes + 22) |= CB_CFIG_VLAN_DROP_ENABLE;
-    }
+        // not in use for e100
 }
 
 #endif
