@@ -58,9 +58,9 @@
 #define I82558_REV_ID                                    4
 #define EEPROM_COMPATIBILITY_FLAGS      3
 #define EEPROM_COMPATIBILITY_BIT_4          0x0004
+#define EEPROM_COMPATIBILITY_BIT_2          0x0002
 #define IPCB_INSERT_VLAN_ENABLE         0x0020
-#define CB_CFIG_LONG_RX_OK              0x0008
-//#define CB_CFIG_VLAN_DROP_ENABLE        0x0002
+
 #define GAMLA_REV_ID                    12
 #define D101B_REV_ID                    5
 
