@@ -136,12 +136,17 @@
 
 #define TX_TCO_PACKETS_TAG              "Tx_TCO_Packets"
 #define RX_TCO_PACKETS_TAG              "Rx_TCO_Packets"
+#define IDENTIFY_ADAPTER				  "Identify_Adapter"
 
 /* E100 compile time configurable parameters */
 
 
 #define   IFNAME   "e100"
 
+/* Power Management */
+#define   PMCSR         0xe0
+#define   PM_ENABLE_BIT 0x0100
+
 /*
  *  Configure parameters for buffers per controller.
  *  If the machine this is being used on is a faster machine (i.e. > 150MHz)
@@ -189,8 +194,11 @@
 #ifdef __ia64__
 #define E100_DEFAULT_UCODE        FALSE
 #else
-#define E100_DEFAULT_UCODE        TRUE
+#define E100_DEFAULT_UCODE        FALSE
 #endif /*  __ia64__ */
+#define E100_DEFAULT_TCO_WORKAROUND_FOR_GAMLA		FALSE
+#define E100_DEFAULT_CPUSAVER_INTERRUPT_DELAY		0
+#define E100_DEFAULT_CPUSAVER_BUNDLE_MAX			6
 
 #define TX_CONG_DFLT   0       /* congestion enable flag for National TX Phy */
 #define TX_FIFO_LMT    0
@@ -203,21 +211,16 @@
 /* These are special #defs and are NOT TO BE TOUCHED! */
 #define DEFAULT_TX_FIFO_LIMIT      0x00
 #define DEFAULT_RX_FIFO_LIMIT      0x08
-#define CB_557_CFIG_DEFAULT_PARM4   0x00
-#define CB_557_CFIG_DEFAULT_PARM5   0x00
 #define DEFAULT_TRANSMIT_THRESHOLD     12   /* 12 -> 96 bytes */
 /* IFS parameters */
 #define MIN_NUMBER_OF_TRANSMITS_100 1000
 #define MIN_NUMBER_OF_TRANSMITS_10  100
 
-/* Note: The 2 parameters below might affect NFS performance. If there are
- * problems with NFS, set CPU_CYCLE_SAVER to 0x0 and CFG_BYTE_PARM6 to 0x32.
- */
+#define MAX_NIC 16
 
-/* CPU_CYCLE_SAVER: Used for receive interrupt bundling microcode. 
- * Valid values are from 0 to 0xc000. Setting it to 0 disables the feature.
+/* Note: The parameter below might affect NFS performance. If there are
+ * problems with NFS, set CFG_BYTE_PARM6 to 0x32.
  */
-#define CPU_CYCLE_SAVER         0x0600
 
 /* CFG_BYTE_PARM6: Determines whether the card generates CNA interrupts
  * or not. 
@@ -686,8 +689,9 @@ typedef struct net_device_stats net_device_stats_t;
 #define EEPROM_NODE_ADDRESS_BYTE_0      0
 #define EEPROM_COMPATIBILITY_WORD       3
 #define EEPROM_PWA_NO                   8
-#define EEPROM_SUBSYSTEM_ID_WORD        0x0b
-#define EEPROM_SUBSYSTEM_VENDOR_WORD    0x0c
+#define EEPROM_ID_WORD			0x0A
+#define EEPROM_SUBSYSTEM_ID_WORD        0x0B
+#define EEPROM_SUBSYSTEM_VENDOR_WORD    0x0C
 
 
 /*
@@ -755,111 +759,10 @@ typedef struct net_device_stats net_device_stats_t;
 /*misc command bits */
 #define CB_TX_EOF_BIT           BIT_15   /* TX CB/TBD EOF Bit */
 
-
-/* Config CB Parameter Fields*/
+/* Config params */
 #define CB_CFIG_BYTE_COUNT          22   /* 22 config bytes */
 #define CB_CFIG_D102_BYTE_COUNT    10          
 
-/* byte 0 bit definitions*/
-#define CB_CFIG_BYTE_COUNT_MASK     BIT_0_5   /* Byte count occupies bit 5-0 */
-
-/* byte 1 bit definitions*/
-#define CB_CFIG_RXFIFO_LIMIT_MASK   BIT_0_4   /* RxFifo limit mask */
-#define CB_CFIG_TXFIFO_LIMIT_MASK   BIT_4_7   /* TxFifo limit mask */
-
-/* byte 2 bit definitions -- ADAPTIVE_IFS*/
-
-/* word 3 bit definitions -- RESERVED*/
-/* Changed for 82558 enhancements */
-/* byte 3 bit definitions */
-#define CB_CFIG_MWI_EN      BIT_0   /* Enable MWI on PCI bus */
-#define CB_CFIG_TYPE_EN     BIT_1   /* Type Enable */
-#define CB_CFIG_READAL_EN   BIT_2   /* Enable Read Align */
-#define CB_CFIG_TERMCL_EN   BIT_3   /* Cache line write  */
-
-/* byte 4 bit definitions*/
-#define CB_CFIG_RX_MIN_DMA_MASK     BIT_0_6   /* Rx minimum DMA count mask */
-
-/* byte 5 bit definitions*/
-#define CB_CFIG_TX_MIN_DMA_MASK BIT_0_6   /* Tx minimum DMA count mask */
-#define CB_CFIG_DMBC_EN         BIT_7   /* Enable Tx/Rx min. DMA counts */
-
-/* Changed for 82558 enhancements */
-/* byte 6 bit definitions*/
-#define CB_CFIG_LATE_SCB           BIT_0   /* Update SCB After New Tx Start */
-#define CB_CFIG_DIRECT_DMA_DIS     BIT_1   /* Direct DMA mode */
-#define CB_CFIG_TNO_INT            BIT_2   /* Tx Not OK Interrupt */
-#define CB_CFIG_TCO_STAT           BIT_2   /* TCO statistics in 559 and above*/
-#define CB_CFIG_CI_INT             BIT_3   /* Command Complete Interrupt */
-#define CB_CFIG_EXT_TCB_DIS        BIT_4   /* Extended TCB */
-#define CB_CFIG_EXT_STAT_DIS       BIT_5   /* Extended Stats */
-#define CB_CFIG_SAVE_BAD_FRAMES    BIT_7   /* Save Bad Frames Enabled */
-
-/* byte 7 bit definitions*/
-#define CB_CFIG_DISC_SHORT_FRAMES   BIT_0   /* Discard Short Frames */
-#define CB_CFIG_URUN_RETRY          BIT_1_2   /* Underrun Retry Count */
-#define CB_CFIG_DYNTBD_EN           BIT_7   /* Enable dynamic TBD */
-/* Enable extended RFD's on D102 */
-#define CB_CFIG_EXTENDED_RFD        BIT_5       
-
-/* byte 8 bit definitions*/
-#define CB_CFIG_503_MII             BIT_0   /* 503 vs. MII mode */
-
-/* byte 9 bit definitions -- pre-defined all zeros*/
-
-/* byte 10 bit definitions*/
-#define CB_CFIG_NO_SRCADR       BIT_3   /* No Source Address Insertion */
-#define CB_CFIG_PREAMBLE_LEN    BIT_4_5   /* Preamble Length */
-#define CB_CFIG_LOOPBACK_MODE   BIT_6_7   /* Loopback Mode */
-
-/* byte 11 bit definitions*/
-#define CB_CFIG_LINEAR_PRIORITY     BIT_0_2   /* Linear Priority */
-
-/* byte 12 bit definitions*/
-#define CB_CFIG_LINEAR_PRI_MODE     BIT_0   /* Linear Priority mode */
-#define CB_CFIG_IFS_MASK            BIT_4_7   /* Interframe Spacing mask */
-
-/* byte 13 bit definitions -- pre-defined all zeros*/
-
-/* byte 14 bit definitions -- pre-defined 0xf2*/
-
-/* byte 15 bit definitions*/
-#define CB_CFIG_PROMISCUOUS         BIT_0   /* Promiscuous Mode Enable */
-#define CB_CFIG_BROADCAST_DIS       BIT_1   /* Broadcast Mode Disable */
-#define CB_CFIG_CRS_OR_CDT          BIT_7   /* CRS Or CDT */
-
-/* byte 16 bit definitions -- pre-defined all zeros*/
-
-/* byte 17 bit definitions -- pre-defined 0x40*/
-
-/* byte 18 bit definitions*/
-#define CB_CFIG_STRIPPING           BIT_0   /* Padding Disabled */
-#define CB_CFIG_PADDING             BIT_1   /* Padding Disabled */
-#define CB_CFIG_CRC_IN_MEM          BIT_2   /* Transfer CRC To Memory */
-
-/* byte 19 bit definitions*/
-#define CB_CFIG_TX_ADDR_WAKE        BIT_0   /* Address Wakeup */
-#define CB_CFIG_TX_MAGPAK_WAKE      BIT_1   /* Magic Packet Wakeup */
-/* Changed TX_FC_EN to TX_FC_DIS because 0 enables, 1 disables. Jul 8, 1999 */
-#define CB_CFIG_TX_FC_DIS           BIT_2   /* Tx Flow Control Disable */
-#define CB_CFIG_FC_RESTOP           BIT_3   /* Rx Flow Control Restop */
-#define CB_CFIG_FC_RESTART          BIT_4   /* Rx Flow Control Restart */
-#define CB_CFIG_REJECT_FC           BIT_5   /* Rx Flow Control Restart */
-/* end 82558/9 specifics */
-#define CB_CFIG_FORCE_FDX           BIT_6   /* Force Full Duplex */
-#define CB_CFIG_FDX_ENABLE          BIT_7   /* Full Duplex Enabled */
-
-/* byte 20 bit definitions*/
-#define CB_CFIG_MULTI_IA            BIT_6   /* Multiple IA Addr */
-
-/* byte 21 bit definitions*/
-#define CB_CFIG_MULTICAST_ALL       BIT_3   /* Multicast All */
-
-/* byte 22 bit defines */
-#define CB_CFIG_RECEIVE_GAMLA_MODE  BIT_0       /* D102 receive mode */
-#define CB_CFIG_VLAN_DROP_ENABLE    BIT_1       /* vlan stripping */
-
-
 
 /* Receive Frame Descriptor Fields */
 
@@ -911,84 +814,6 @@ typedef struct net_device_stats net_device_stats_t;
                 CB_SELFTEST_REGISTER_BIT | CB_SELFTEST_ROM_BIT)
 
 
-/*-------------------------------------------------------------------------
- * Driver Configuration Default Parameters for the 557
- *  Note: If the driver uses any defaults that are different from the chip's
- *        defaults, it will be noted below
- *-------------------------------------------------------------------------
- */
-/* Byte 0 (byte count) default*/
-#define CB_557_CFIG_DEFAULT_PARM0   CB_CFIG_BYTE_COUNT
-
-/* Byte 1 (fifo limits) default ( bit 7 is always set ) */
-#define CB_557_CFIG_DEFAULT_PARM1   0x88
-
-/* Byte 2 (adaptive IFS) default*/
-#define CB_557_CFIG_DEFAULT_PARM2   0x00
-
-/* Byte 3 (reserved) default*/
-#define CB_557_CFIG_DEFAULT_PARM3   0x00
-
-/* Byte 4 (Rx DMA min count) default*/
-#define CB_557_CFIG_DEFAULT_PARM4   0x00
-
-/* Byte 5 (Tx DMA min count, DMA min count enable) default*/
-#define CB_557_CFIG_DEFAULT_PARM5   0x00
-
-/* Byte 6 (No Late SCB, CNA int) default*/
-#define CB_557_CFIG_DEFAULT_PARM6   0x32
-
-/* Byte 7 (Discard short frames, underrun retry) default*/
-/*          note: disc short frames will be enabled*/
-#define DEFAULT_UNDERRUN_RETRY      0x01
-#define CB_557_CFIG_DEFAULT_PARM7   0x03
-
-/* Byte 8 (MII or 503) default*/
-/*          note: MII will be the default*/
-#define CB_557_CFIG_DEFAULT_PARM8   0x01
-
-/* Byte 9 (reserved) default*/
-#define CB_557_CFIG_DEFAULT_PARM9   0x00
-
-/* Byte 10 (scr addr insertion, preamble, loopback) default*/
-#define CB_557_CFIG_DEFAULT_PARM10  0x2e
-
-/* Byte 11 (linear priority) default*/
-#define CB_557_CFIG_DEFAULT_PARM11  0x00
-
-/* Byte 12 (IFS,linear priority mode) default*/
-#define CB_557_CFIG_DEFAULT_PARM12  0x60
-
-/* Byte 13 (reserved) default*/
-#define CB_557_CFIG_DEFAULT_PARM13  0x00
-
-/* Byte 14 (reserved) default*/
-#define CB_557_CFIG_DEFAULT_PARM14  0xf2
-
-/* Byte 15 (broadcast, CRS/CDT) default*/
-#define CB_557_CFIG_DEFAULT_PARM15  0xc8
-
-/* Byte 16 (reserved) default*/
-#define CB_557_CFIG_DEFAULT_PARM16  0x00
-
-/* Byte 17 (reserved) default*/
-#define CB_557_CFIG_DEFAULT_PARM17  0x40
-
-/* Byte 18 (Stripping, padding, Rcv CRC in mem) default*/
-/*          note: padding is enabled with 0xf2, disabled if 0xf0 */
-#define CB_557_CFIG_DEFAULT_PARM18  0xf2
-
-/* Byte 19 (reserved) default*/
-/*          note: full duplex is enabled if FDX# pin is 0*/
-#define CB_557_CFIG_DEFAULT_PARM19  0x80
-
-/* Byte 20 (multi-IA) default*/
-#define CB_557_CFIG_DEFAULT_PARM20  0x3f
-
-/* Byte 21 (multicast all) default*/
-#define CB_557_CFIG_DEFAULT_PARM21  0x05
-
-
 /* 82557 PCI Register Definitions */
 /* Refer To The PCI Specification For Detailed Explanations*/
 
@@ -1096,6 +921,8 @@ typedef struct net_device_stats net_device_stats_t;
 												* of Frame Error Counter */
 #define PHY_82555_EOF_COUNTER    		0x18   /* 82555 end of frame error counter */
 #define PHY_82555_MDI_EQUALIZER_CSR     0x1a   /* 82555 specific equalizer reg. */
+#define PHY_82555_LED_SWITCH_CONTROL    	0x1b   /* 82555 led switch control register */
+
 
 /* 82555 CSR bits */
 #define PHY_82555_SPEED_BIT       BIT_1
@@ -1109,6 +936,31 @@ typedef struct net_device_stats net_device_stats_t;
 #define DISABLE_AUTO_POLARITY       0x0010
 #define EXTENDED_SQUELCH_BIT         BIT_2
 
+/* 82555 led switch control reg. opcodes */
+#define PHY_82555_LED_NORMAL_CONTROL			0					// control back to the 8255X
+#define PHY_82555_LED_DRIVER_CONTROL			BIT_2				// the driver is in control
+#define PHY_82555_LED_OFF						BIT_2              	// activity LED is off
+#define PHY_82555_LED_ON_559					(BIT_0 | BIT_2)        // activity LED is on for 559 and later
+#define PHY_82555_LED_ON_PRE_559				(BIT_0 | BIT_1 | BIT_2)// activity LED is on for 558 and before
+
+
+// Describe the state of the phy led.
+// needed for the function : 'e100_blink_timer'
+enum led_state_e	{
+	LED_OFF,	
+	LED_ON,
+	LED_NORMAL /* led is on and off by the 8255x */
+
+};
+
+//number of led blinks per second.
+#define BLINK_PER_SECOND		4
+
+
+
+
+
+
 /* ############End of 82555 specific defines##################### */
 
 /* MDI Control register bit definitions*/
@@ -1407,12 +1259,13 @@ typedef struct _udp_header_
 } udp_header, *pudp_header;
 
 /* checksumming function prototypes */
-static boolean_t e100_calculate_checksum (ip_v4_header * IPPacket,
-    uint32_t HeaderOffset,
-    struct sk_buff *skb,
-    uint32_t packetSize);
+boolean_t e100_calculate_checksum (ip_v4_header * IPPacket,
+                                   uint32_t HeaderOffset,
+                                   struct sk_buff *skb,
+                                   uint32_t packetSize);
 ip_v4_header *e100_check_for_ip (int *HeaderOffset, struct sk_buff *skb);
 
+void e100_blink_timer(device_t * dev);
 
 #define   E100_NAME         "e100"
 
@@ -1437,6 +1290,18 @@ typedef struct net_device_stats net_dev_stats_t;
 /* leave a gap of 2 TCB's in e100_tx_srv */
 #define IS_IT_GAP(X) (NEXT_TCB_TOUSE(NEXT_TCB_TOUSE((X)->head))==(X)->tail)
 
+#define DELAY_LOOP_USEC		4 	
+
+#define E100_WAIT_FOR_CONDITION(timeout,expr)	\
+{						\
+  while(!(expr) && ((timeout) > 0) ){		\
+    udelay( DELAY_LOOP_USEC);			\
+    (timeout) -= DELAY_LOOP_USEC;		\
+  }						\
+}
+
+
+
 /* Macro to see if address is a Multicast address. Jun 22, 1999 */
 #define IS_VALID_MULTICAST(x)  ((x)->bytes[0] & 0x1 )
 
@@ -1448,6 +1313,7 @@ typedef struct net_device_stats net_dev_stats_t;
 #define mk_pci_dev_id(X,Y)      (((X)<<8)|((Y)&PCI_DEV_NO))
 
 #define E100_MIN(X,Y)         ( (X) < (Y)? (X):(Y) )
+#define E100_MAX(X,Y)         ( (X) > (Y)? (X):(Y) )
 #define RFD_POINTER(X,Y)      ((rfd_t *) (((unsigned char *)((X)->data))-((Y)->rfd_size)))
 #define SKB_RFD_STATUS(X,Y) ((RFD_POINTER((X),(Y)))->rfd_header.cb_status)
 #define NEXT_SKB(X,Y)         ((RFD_POINTER((X),(Y)))->next)   
@@ -1571,7 +1437,7 @@ typedef struct _d102_scb_ext_t
  * the bdd, which hangs of the bdp. This is the brain of it.
  */
 typedef struct _scb_t
-{
+{               
     volatile uint16_t scb_status;  /* SCB Status register */
     volatile uint8_t scb_cmd_low;   /* SCB Command register (low byte) */
     volatile uint8_t scb_cmd_hi; /* SCB Command register (high byte) */
@@ -1713,7 +1579,7 @@ typedef struct _ia_cb_t
 typedef struct _config_cb_t
 {
     cb_header_t cfg_cbhdr;
-    uint8_t cfg_byte[CB_CFIG_BYTE_COUNT];
+    uint8_t cfg_byte[CB_CFIG_BYTE_COUNT + CB_CFIG_D102_BYTE_COUNT];
 } config_cb_t, *pconfig_cb_t __attribute__ ((__packed__));
 
 
@@ -1900,6 +1766,50 @@ typedef struct _rbd_t
     uint16_t rbd_filler1;
 } rbd_t, *prbd_t __attribute__ ((__packed__));
 
+// this is the size of the eeprom buffer
+// if there is ever an eeprom larger than 256 words,
+// this value needs to change
+
+#define EEPROM_MAX_WORD_SIZE  256
+
+// for buffering data for eeprom reads
+typedef struct _EEPROM_DATA
+{
+    // initialization completed?
+         boolean_t Initialized;
+
+    // currently initializing?
+        boolean_t Initializing;
+    
+    // eeprom size
+    __u16  Size;   
+
+        //the data (in words)
+        __u16  Data[EEPROM_MAX_WORD_SIZE];
+
+} EEPROM_DATA, *PEEPROM_DATA;
+
+
+#ifdef CONFIG_PROC_FS
+
+/* Blink Led structure - enable adpter idntifing by blinking the NIC led */
+
+typedef struct _blink_led_t 
+{
+    
+    struct timer_list 	blink_led_timer; 
+	enum led_state_e 	blink_state;	
+	uint16_t 			blink_count;    
+    boolean_t			blink_is_running;  
+    boolean_t			at_cleanup;    
+    spinlock_t 			blink_led_lock;
+
+} blink_led_t, *pblink_t ;
+#endif /*CONFIG_PROC_FS*/
+
+
+
+
 /*
  * This structure is used to maintain a FIFO access to a resource that is 
  * maintained as a circular queue. The resource to be maintained is pointed
@@ -1915,6 +1825,9 @@ typedef struct _buf_pool_t
     void *data;                    /* points to resource pool */
 } buf_pool_t, *pbuf_pool_t;
 
+enum next_cu_cmd_e	{ RESUME_NO_WAIT = 0, RESUME_WAIT, START_WAIT  };
+
+
 typedef struct _bdd_t
 {
     uint_t bd_number;              /*  Board Number */
@@ -1931,6 +1844,7 @@ typedef struct _bdd_t
     pdump_area_t pdump_area;     /* pointer to 82557 reg. dump area */
     dma_addr_t dump_paddr;           /* phys addr of dump area */
     pnxmit_cb_t pntcb;           /* pointer to non xmit tcb */
+    tcb_t *last_tcbp;              /* pointer to last tcb sent */
     dma_addr_t nontx_paddr;           /* phys addr of  non-tx tcb */
     perr_stats_t perr_stats;     /* ptr to error statictics results */
     dma_addr_t estat_paddr;           /* phys addr of  err stat results */
@@ -1951,8 +1865,8 @@ typedef struct _bdd_t
     uint8_t perm_node_address[ETHERNET_ADDRESS_LENGTH]; 
     uint32_t pwa_no;              /* PWA: xxxxxx-0xx */
     uint8_t tx_thld;              /* stores transmit threshold */
-    uint8_t prev_cu_cmd;           /* determines CU state - idle/susp */
-    uint8_t prev_scb_cmd;        /* last actual cmd */
+        //    uint8_t prev_cu_cmd;           /* determines CU state - idle/susp */
+        enum next_cu_cmd_e next_cu_cmd;
     int brdcst_dsbl;           /* if set, disables broadcast */
     int mulcst_enbl;           /* if set, enables all multicast */
     int promisc;
@@ -1973,7 +1887,6 @@ typedef struct _bdd_t
     uint16_t dev_id;
     uint16_t sub_ven_id;
     uint16_t sub_dev_id;
-    uint16_t pci_cmd_word;
     uint8_t rev_id;
     uint8_t dev_num;
 
@@ -1989,18 +1902,18 @@ typedef struct _bdd_t
     struct bdconfig *bdp;        /* pointer back to the bd_config */
     /* Lock defintions for the driver */
     spinlock_t bd_lock;           /* board lock */
-    spinlock_t bd_intr_lock;     /* Interrupt lock */
     spinlock_t bd_tx_lock;        /* Transmit lock  */
-    spinlock_t bd_rx_lock;        /* Receive lock   */
-    spinlock_t bd_srv_lock;        /* Service routine lock */
+    spinlock_t config_lock;        /* config block lock */
     
+    spinlock_t watchdog_lock;	/* watchdog lock - to allow timer deleting at e100_close */
+    boolean_t at_device_close;	/* flag - set at close and prevent watchdog timer adding*/ 
     /* Linux statistics */
     struct net_device_stats net_stats;
 
     uint16_t rfd_size;
 } bdd_t, *pbdd_t;
 
-enum zero_lock_state_e { ZLOCK_INITIAL, ZLOCK_READING, ZLOCK_SLEEPING };
+enum zero_lock_state_e	{ ZLOCK_INITIAL, ZLOCK_READING, ZLOCK_SLEEPING };
 
 struct bdconfig
 {
@@ -2018,29 +1931,18 @@ struct bdconfig
     int irq_level;                /* interrupt request level      */
     int bd_number;                /* board number in multi-board setup */
     int flags;                    /* board management flags     */
-    int tx_flags;                 /* tx management flags       */
-    int rx_flags;                 /* rx management flags       */
-    struct tq_struct bh_task;     /* the way to run bh */
     struct timer_list timer_id;   /* watchdog timer ID                  */
     int timer_val;                /* watchdog timer value              */
-    int multicast_cnt;            /* count of multicast address sets   */
     e100_eaddr_t eaddr;           /* Ethernet address storage        */
-    int Bound;                    /* flag for MAC_BIND_REQ */
-    bdd_t *bddp;
-    caddr_t rx_srv_count;
+ bdd_t *bddp;
     caddr_t pci_dev_id;
-    caddr_t irq_link;
-    uint_t tx_count;
-
+        uint_t tx_count;
+        EEPROM_DATA EepromData;
     /* these are linux only */
-    struct sk_buff *last_mp_fail;
-    device_t *device;
+     device_t *device;
   pci_dev_t *ppci_dev;
-    uint8_t pci_bus;
-    uint8_t pci_dev_fun;
-    uint16_t vendor;
-    int tx_out_res;
-
+     uint16_t vendor;
+ 
 	
 	enum zero_lock_state_e ZeroLockState;
 	uint8_t ZeroLockReadData[16]; 
@@ -2050,9 +1952,17 @@ struct bdconfig
 	uint16_t ErrorCounter; 
 #endif
     
+    uint8_t config[CB_CFIG_BYTE_COUNT + CB_CFIG_D102_BYTE_COUNT];
+    
     
     uint8_t ifs_state;
     uint8_t ifs_value;
+
+
+#ifdef CONFIG_PROC_FS
+	blink_led_t blink_led; /* enable adpter idntifing by blinking the NIC led */
+#endif /*CONFIG_PROC_FS*/
+
 };
 
 #ifndef _BD_CONFIG_T_
@@ -2101,896 +2011,6 @@ typedef struct _e100_vendor_info_t
 
 extern e100_vendor_info_t e100_vendor_info_array[];
 
-
-/*************************************************************************/
-/*            Receive Interrupt Bundling Microcode (CPUsaver)            */
-/*************************************************************************/
-
-
-/*************************************************************************
-*  CPUSaver parameters
-*
-*  All CPUSaver parameters are 16-bit literals that are part of a
-*  "move immediate value" instruction.  By changing the value of
-*  the literal in the instruction before the code is loaded, the
-*  driver can change algorithm.
-*
-*  CPUSAVER_DWORD - This is the location of the instruction that loads
-*    the dead-man timer with its inital value.  By writing a 16-bit
-*    value to the low word of this instruction, the driver can change
-*    the timer value.  The current default is either x600 or x800;
-*    experiments show that the value probably should stay within the
-*    range of x200 - x1000.
-*
-*  CPUSAVER_BUNDLE_MAX_DWORD - This is the location of the instruction
-*    that sets the maximum number of frames that will be bundled.  In
-*    some situations, such as the TCP windowing algorithm, it may be
-*    better to limit the growth of the bundle size than let it go as
-*    high as it can, because that could cause too much added latency.
-*    The default is six, because this is the number of packets in the
-*    default TCP window size.  A value of 1 would make CPUSaver indicate
-*    an interrupt for every frame received.  If you do not want to put
-*    a limit on the bundle size, set this value to xFFFF.
-*
-*  CPUSAVER_MIN_SIZE_DWORD - This is the location of the instruction
-*    that contains a bit-mask describing the minimum size frame that
-*    will be bundled.  The default masks the lower 7 bits, which means
-*    that any frame less than 128 bytes in length will not be bundled,
-*    but will instead immediately generate an interrupt.  This does
-*    not affect the current bundle in any way.  Any frame that is 128
-*    bytes or large will be bundled normally.  This feature is meant
-*    to provide immediate indication of ACK frames in a TCP environment.
-*    Customers were seeing poor performance when a machine with CPUSaver
-*    enabled was sending but not receiving.  The delay introduced when
-*    the ACKs were received was enough to reduce total throughput, because
-*    the sender would sit idle until the ACK was finally seen.
-*
-*    The current default is 0xFF80, which masks out the lower 7 bits.
-*    This means that any frame which is x7F (127) bytes or smaller
-*    will cause an immediate interrupt.  Because this value must be a 
-*    bit mask, there are only a few valid values that can be used.  To
-*    turn this feature off, the driver can write the value xFFFF to the
-*    lower word of this instruction (in the same way that the other
-*    parameters are used).  Likewise, a value of 0xF800 (2047) would
-*    cause an interrupt to be generated for every frame, because all
-*    standard Ethernet frames are <= 2047 bytes in length.
-*************************************************************************/
-
-
-
-/********************************************************/
-/*  CPUSaver micro code for the D101A                   */
-/********************************************************/
-
-/*  Version 2.0  */
-
-/*  This value is the same for both A and B step of 558.  */
-#define D101_CPUSAVER_DWORD         72
-
-
-#define     D101_A_RCVBUNDLE_UCODE \
-{\
-0x03B301BB, \
-0x0046FFFF, \
-0xFFFFFFFF, \
-0x051DFFFF, \
-0xFFFFFFFF, \
-0xFFFFFFFF, \
-0x000C0001, \
-0x00101212, \
-0x000C0008, \
-0x003801BC, \
-0x00000000, \
-0x00124818, \
-0x000C1000, \
-0x00220809, \
-0x00010200, \
-0x00124818, \
-0x000CFFFC, \
-0x003803B5, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x0010009C, \
-0x0024B81D, \
-0x00130836, \
-0x000C0001, \
-0x0026081C, \
-0x0020C81B, \
-0x00130824, \
-0x00222819, \
-0x00101213, \
-0x00041000, \
-0x003A03B3, \
-0x00010200, \
-0x00101B13, \
-0x00238081, \
-0x00213049, \
-0x0038003B, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x0010009C, \
-0x0024B83E, \
-0x00130826, \
-0x000C0001, \
-0x0026083B, \
-0x00010200, \
-0x00134824, \
-0x000C0001, \
-0x00101213, \
-0x00041000, \
-0x0038051E, \
-0x00101313, \
-0x00010400, \
-0x00380521, \
-0x00050600, \
-0x00100824, \
-0x00101310, \
-0x00041000, \
-0x00080600, \
-0x00101B10, \
-0x0038051E, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-}
-
-
-/********************************************************/
-/*  CPUSaver micro code for the D101B                   */
-/********************************************************/
-
-/*  Version 2.0  */
-
-#define     D101_B0_RCVBUNDLE_UCODE \
-{\
-0x03B401BC, \
-0x0047FFFF, \
-0xFFFFFFFF, \
-0x051EFFFF, \
-0xFFFFFFFF, \
-0xFFFFFFFF, \
-0x000C0001, \
-0x00101B92, \
-0x000C0008, \
-0x003801BD, \
-0x00000000, \
-0x00124818, \
-0x000C1000, \
-0x00220809, \
-0x00010200, \
-0x00124818, \
-0x000CFFFC, \
-0x003803B6, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x0010009C, \
-0x0024B81D, \
-0x0013082F, \
-0x000C0001, \
-0x0026081C, \
-0x0020C81B, \
-0x00130837, \
-0x00222819, \
-0x00101B93, \
-0x00041000, \
-0x003A03B4, \
-0x00010200, \
-0x00101793, \
-0x00238082, \
-0x0021304A, \
-0x0038003C, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x0010009C, \
-0x0024B83E, \
-0x00130826, \
-0x000C0001, \
-0x0026083B, \
-0x00010200, \
-0x00134837, \
-0x000C0001, \
-0x00101B93, \
-0x00041000, \
-0x0038051F, \
-0x00101313, \
-0x00010400, \
-0x00380522, \
-0x00050600, \
-0x00100837, \
-0x00101310, \
-0x00041000, \
-0x00080600, \
-0x00101790, \
-0x0038051F, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-}
-
-
-/********************************************************/
-/*  CPUSaver micro code for the D101M (B-step only)     */
-/********************************************************/
-
-/*  Version 2.10  */
-
-/*  Parameter values for the D101M B-step  */
-#define D101M_CPUSAVER_DWORD                78
-#define D101M_CPUSAVER_BUNDLE_MAX_DWORD     65
-#define D101M_CPUSAVER_MIN_SIZE_DWORD       126
-
-
-#define D101M_B_RCVBUNDLE_UCODE \
-{\
-0x00550215, \
-0xFFFF0437, \
-0xFFFFFFFF, \
-0x06A70789, \
-0xFFFFFFFF, \
-0x0558FFFF, \
-0x000C0001, \
-0x00101312, \
-0x000C0008, \
-0x00380216, \
-0x0010009C, \
-0x00204056, \
-0x002380CC, \
-0x00380056, \
-0x0010009C, \
-0x00244C0B, \
-0x00000800, \
-0x00124818, \
-0x00380438, \
-0x00000000, \
-0x00140000, \
-0x00380555, \
-0x00308000, \
-0x00100662, \
-0x00100561, \
-0x000E0408, \
-0x00134861, \
-0x000C0002, \
-0x00103093, \
-0x00308000, \
-0x00100624, \
-0x00100561, \
-0x000E0408, \
-0x00100861, \
-0x000C007E, \
-0x00222C21, \
-0x000C0002, \
-0x00103093, \
-0x00380C7A, \
-0x00080000, \
-0x00103090, \
-0x00380C7A, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x0010009C, \
-0x00244C2D, \
-0x00010004, \
-0x00041000, \
-0x003A0437, \
-0x00044010, \
-0x0038078A, \
-0x00000000, \
-0x00100099, \
-0x00206C7A, \
-0x0010009C, \
-0x00244C48, \
-0x00130824, \
-0x000C0001, \
-0x00101213, \
-0x00260C75, \
-0x00041000, \
-0x00010004, \
-0x00130826, \
-0x000C0006, \
-0x002206A8, \
-0x0013C926, \
-0x00101313, \
-0x003806A8, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00080600, \
-0x00101B10, \
-0x00050004, \
-0x00100826, \
-0x00101210, \
-0x00380C34, \
-0x00000000, \
-0x00000000, \
-0x0021155B, \
-0x00100099, \
-0x00206559, \
-0x0010009C, \
-0x00244559, \
-0x00130836, \
-0x000C0000, \
-0x00220C62, \
-0x000C0001, \
-0x00101B13, \
-0x00229C0E, \
-0x00210C0E, \
-0x00226C0E, \
-0x00216C0E, \
-0x0022FC0E, \
-0x00215C0E, \
-0x00214C0E, \
-0x00380555, \
-0x00010004, \
-0x00041000, \
-0x00278C67, \
-0x00040800, \
-0x00018100, \
-0x003A0437, \
-0x00130826, \
-0x000C0001, \
-0x00220559, \
-0x00101313, \
-0x00380559, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00130831, \
-0x0010090B, \
-0x00124813, \
-0x000CFF80, \
-0x002606AB, \
-0x00041000, \
-0x003806A8, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-}
-
-
-/********************************************************/
-/*  CPUSaver micro code for the D101S                   */
-/********************************************************/
-
-/*  Version 1.20  */
-
-/*  Parameter values for the D101S  */
-#define D101S_CPUSAVER_DWORD                78
-#define D101S_CPUSAVER_BUNDLE_MAX_DWORD     67
-#define D101S_CPUSAVER_MIN_SIZE_DWORD       129
-
-
-#define D101S_RCVBUNDLE_UCODE \
-{\
-0x00550242, \
-0xFFFF047E, \
-0xFFFFFFFF, \
-0x06FF0818, \
-0xFFFFFFFF, \
-0x05A6FFFF, \
-0x000C0001, \
-0x00101312, \
-0x000C0008, \
-0x00380243, \
-0x0010009C, \
-0x00204056, \
-0x002380D0, \
-0x00380056, \
-0x0010009C, \
-0x00244F8B, \
-0x00000800, \
-0x00124818, \
-0x0038047F, \
-0x00000000, \
-0x00140000, \
-0x003805A3, \
-0x00308000, \
-0x00100610, \
-0x00100561, \
-0x000E0408, \
-0x00134861, \
-0x000C0002, \
-0x00103093, \
-0x00308000, \
-0x00100624, \
-0x00100561, \
-0x000E0408, \
-0x00100861, \
-0x000C007E, \
-0x00222FA1, \
-0x000C0002, \
-0x00103093, \
-0x00380F90, \
-0x00080000, \
-0x00103090, \
-0x00380F90, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x0010009C, \
-0x00244FAD, \
-0x00010004, \
-0x00041000, \
-0x003A047E, \
-0x00044010, \
-0x00380819, \
-0x00000000, \
-0x00100099, \
-0x00206FFD, \
-0x0010009A, \
-0x0020AFFD, \
-0x0010009C, \
-0x00244FC8, \
-0x00130824, \
-0x000C0001, \
-0x00101213, \
-0x00260FF8, \
-0x00041000, \
-0x00010004, \
-0x00130826, \
-0x000C0006, \
-0x00220700, \
-0x0013C926, \
-0x00101313, \
-0x00380700, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00080600, \
-0x00101B10, \
-0x00050004, \
-0x00100826, \
-0x00101210, \
-0x00380FB6, \
-0x00000000, \
-0x00000000, \
-0x002115A9, \
-0x00100099, \
-0x002065A7, \
-0x0010009A, \
-0x0020A5A7, \
-0x0010009C, \
-0x002445A7, \
-0x00130836, \
-0x000C0000, \
-0x00220FE4, \
-0x000C0001, \
-0x00101B13, \
-0x00229F8E, \
-0x00210F8E, \
-0x00226F8E, \
-0x00216F8E, \
-0x0022FF8E, \
-0x00215F8E, \
-0x00214F8E, \
-0x003805A3, \
-0x00010004, \
-0x00041000, \
-0x00278FE9, \
-0x00040800, \
-0x00018100, \
-0x003A047E, \
-0x00130826, \
-0x000C0001, \
-0x002205A7, \
-0x00101313, \
-0x003805A7, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00130831, \
-0x0010090B, \
-0x00124813, \
-0x000CFF80, \
-0x00260703, \
-0x00041000, \
-0x00380700, \
-0x00000000, \
-}
-
-
-/********************************************************/
-/*  CPUSaver micro code for the D102 B-step            */
-/********************************************************/
-
-/*  Version 1.00  */
-
-/*  Parameter values for the D102 B-step  */
-#define D102_B_CPUSAVER_DWORD                78
-#define D102_B_CPUSAVER_BUNDLE_MAX_DWORD     67
-#define D102_B_CPUSAVER_MIN_SIZE_DWORD       116
-
-
-#define     D102_B_RCVBUNDLE_UCODE \
-{\
-0x006f0276, \
-0xffff04d2, \
-0xffffffff, \
-0x0ed4ffff, \
-0xffffffff, \
-0x0d20ffff, \
-0x00300001, \
-0x0140D871, \
-0x00300008, \
-0x00E00277, \
-0x01406C59, \
-0x00804073, \
-0x008700FA, \
-0x00E00070, \
-0x01406C59, \
-0x00905F8B, \
-0x00001000, \
-0x01496F50, \
-0x00E004D3, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00C08000, \
-0x01600CA2, \
-0x01600ADA, \
-0x00380408, \
-0x014D6FDA, \
-0x00300002, \
-0x0140DA72, \
-0x00C08000, \
-0x01700C0B, \
-0x01600ADA, \
-0x00380408, \
-0x01406FDA, \
-0x0030003E, \
-0x00845FA1, \
-0x00300002, \
-0x0140DA72, \
-0x00E01F90, \
-0x00200000, \
-0x0140DA6F, \
-0x00E01F90, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x01406C51, \
-0x0080DFF0, \
-0x01406C52, \
-0x00815FF0, \
-0x01406C59, \
-0x00905FC8, \
-0x014C6FD9, \
-0x00300001, \
-0x0140D972, \
-0x00941FEB, \
-0x00102000, \
-0x00048002, \
-0x014C6FD8, \
-0x00300006, \
-0x00840ED5, \
-0x014F71D8, \
-0x0140D872, \
-0x00E00ED5, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00200600, \
-0x0140D76F, \
-0x00148002, \
-0x01406FD8, \
-0x0140D96F, \
-0x00E01FB6, \
-0x00000000, \
-0x00000000, \
-0x00822D2B, \
-0x01406C51, \
-0x0080CD21, \
-0x01406C52, \
-0x00814D21, \
-0x01406C59, \
-0x00904D21, \
-0x014C6FD7, \
-0x00300000, \
-0x00841FE0, \
-0x00300001, \
-0x0140D772, \
-0x00E0129A, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00048002, \
-0x00102000, \
-0x00971FE5, \
-0x00101000, \
-0x00050200, \
-0x00E804D2, \
-0x014C6FD8, \
-0x00300001, \
-0x00840D21, \
-0x0140D872, \
-0x00E00D21, \
-0x014C6F91, \
-0x0150710B, \
-0x01496F72, \
-0x0030FF80, \
-0x00940ED8, \
-0x00102000, \
-0x00E00ED5, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-}
-
-
-
-/********************************************************/
-/*  Micro code for the D102 C-step                      */
-/********************************************************/
-
-/*  Parameter values for the D102 C-step  */
-#define D102_C_CPUSAVER_DWORD                46
-#define D102_C_CPUSAVER_BUNDLE_MAX_DWORD     54
-#define D102_C_CPUSAVER_MIN_SIZE_DWORD      133 /* not implemented */
-
-#define     D102_C_RCVBUNDLE_UCODE \
-{\
-0x00700279, \
-0x0e6604e2, \
-0x02bf0cae, \
-0x1519150c, \
-0xFFFFFFFF, \
-0xffffFFFF, \
-0x00E014D8, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00E014DC, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00E014F4, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00E014E0, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00E014E7, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00141000, \
-0x015D6F0D, \
-0x00E002C0, \
-0x00000000, \
-0x00200600, \
-0x00E0150D, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00300006, \
-0x00E0151A, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-0x00000000, \
-}
-
-
-
 #endif
 
 
